[nautilus-actions] NadpFormats class is renamed to FMAFormats



commit 6e9bc47fc6f095a2e0fe894a1a3b8842a0816119
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Sep 8 14:45:25 2015 +0200

    NadpFormats class is renamed to FMAFormats

 src/io-desktop/Makefile.am                       |    4 +-
 src/io-desktop/fma-desktop-provider.c            |    6 ++--
 src/io-desktop/{nadp-formats.c => fma-formats.c} |   30 +++++++++++-----------
 src/io-desktop/{nadp-formats.h => fma-formats.h} |   10 +++---
 src/io-desktop/nadp-writer.c                     |    2 +-
 5 files changed, 26 insertions(+), 26 deletions(-)
---
diff --git a/src/io-desktop/Makefile.am b/src/io-desktop/Makefile.am
index aa17072..802761b 100644
--- a/src/io-desktop/Makefile.am
+++ b/src/io-desktop/Makefile.am
@@ -45,8 +45,8 @@ libna_io_desktop_la_SOURCES = \
        fma-desktop-file.h                                                                      \
        fma-desktop-provider.c                                                          \
        fma-desktop-provider.h                                                          \
-       nadp-formats.c                                                                          \
-       nadp-formats.h                                                                          \
+       fma-formats.c                                                                           \
+       fma-formats.h                                                                           \
        nadp-keys.c                                                                                     \
        nadp-keys.h                                                                                     \
        nadp-module.c                                                                           \
diff --git a/src/io-desktop/fma-desktop-provider.c b/src/io-desktop/fma-desktop-provider.c
index 2f51e20..b3b7b23 100644
--- a/src/io-desktop/fma-desktop-provider.c
+++ b/src/io-desktop/fma-desktop-provider.c
@@ -38,7 +38,7 @@
 #include <api/fma-ifactory-provider.h>
 
 #include "fma-desktop-provider.h"
-#include "nadp-formats.h"
+#include "fma-formats.h"
 #include "nadp-keys.h"
 #include "nadp-monitor.h"
 #include "nadp-reader.h"
@@ -328,13 +328,13 @@ iexporter_get_name( const FMAIExporter *exporter )
 static void *
 iexporter_get_formats( const FMAIExporter *exporter )
 {
-       return(( void * ) nadp_formats_get_formats( exporter ));
+       return(( void * ) fma_formats_get_formats( exporter ));
 }
 
 static void
 iexporter_free_formats( const FMAIExporter *exporter, GList *format_list )
 {
-       nadp_formats_free_formats( format_list );
+       fma_formats_free_formats( format_list );
 }
 
 /**
diff --git a/src/io-desktop/nadp-formats.h b/src/io-desktop/fma-formats.h
similarity index 86%
rename from src/io-desktop/nadp-formats.h
rename to src/io-desktop/fma-formats.h
index 484040e..62a8f76 100644
--- a/src/io-desktop/nadp-formats.h
+++ b/src/io-desktop/fma-formats.h
@@ -27,8 +27,8 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __NADP_FORMATS_H__
-#define __NADP_FORMATS_H__
+#ifndef __FMA_FORMATS_H__
+#define __FMA_FORMATS_H__
 
 #include <glib.h>
 
@@ -38,9 +38,9 @@ G_BEGIN_DECLS
 
 #define NADP_FORMAT_DESKTOP_V1                 "Desktop1"
 
-GList *nadp_formats_get_formats ( const FMAIExporter *exporter );
-void   nadp_formats_free_formats( GList *formats );
+GList *fma_formats_get_formats ( const FMAIExporter *exporter );
+void   fma_formats_free_formats( GList *formats );
 
 G_END_DECLS
 
-#endif /* __NADP_FORMATS_H__ */
+#endif /* __FMA_FORMATS_H__ */
diff --git a/src/io-desktop/nadp-writer.c b/src/io-desktop/nadp-writer.c
index 9367578..41b7583 100644
--- a/src/io-desktop/nadp-writer.c
+++ b/src/io-desktop/nadp-writer.c
@@ -41,7 +41,7 @@
 
 #include "fma-desktop-file.h"
 #include "fma-desktop-provider.h"
-#include "nadp-formats.h"
+#include "fma-formats.h"
 #include "nadp-keys.h"
 #include "nadp-utils.h"
 #include "nadp-writer.h"


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/io-desktop/nadp-formats.c b/src/io-desktop/fma-formats.c
similarity index 84%
rename from src/io-desktop/nadp-formats.c
rename to src/io-desktop/fma-formats.c
index 396a375..3097d3e 100644
--- a/src/io-desktop/nadp-formats.c
+++ b/src/io-desktop/fma-formats.c
@@ -37,7 +37,7 @@
 
 #include <api/fma-iexporter.h>
 
-#include "nadp-formats.h"
+#include "fma-formats.h"
 
 typedef struct {
        gchar *format;
@@ -47,7 +47,7 @@ typedef struct {
 }
        NadpExportFormat;
 
-static NadpExportFormat nadp_formats[] = {
+static NadpExportFormat fma_formats[] = {
 
        /* DESKTOP_V1: the initial desktop format as described in
         * http://www.filemanager-actions.org/?q=node/377
@@ -74,20 +74,20 @@ static void on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf )
 #endif
 
 /**
- * nadp_formats_get_formats:
+ * fma_formats_get_formats:
  * @exporter: this #FMAIExporter provider.
  *
  * Returns: a #GList of the #FMAIExporterFormatv2 supported export formats.
  *
  * This list should be nadp_formats_free_formats() by the caller.
  *
  * Since: 3.2
  */
 GList *
-nadp_formats_get_formats( const FMAIExporter* exporter )
+fma_formats_get_formats( const FMAIExporter* exporter )
 {
 #if 0
-       static const gchar *thisfn = "nadp_formats_get_formats";
+       static const gchar *thisfn = "fma_formats_get_formats";
 #endif
        GList *str_list;
        FMAIExporterFormatv2 *str;
@@ -101,15 +101,15 @@ nadp_formats_get_formats( const FMAIExporter* exporter )
                width = height = 48;
        }
 
-       for( i = 0 ; nadp_formats[i].format ; ++i ){
+       for( i = 0 ; fma_formats[i].format ; ++i ){
                str = g_new0( FMAIExporterFormatv2, 1 );
                str->version = 2;
                str->provider = FMA_IEXPORTER( exporter );
-               str->format = g_strdup( nadp_formats[i].format );
-               str->label = g_strdup( gettext( nadp_formats[i].label ));
-               str->description = g_strdup( gettext( nadp_formats[i].description ));
-               if( nadp_formats[i].image ){
-                       fname = g_strdup_printf( "%s/%s", PROVIDER_DATADIR, nadp_formats[i].image );
+               str->format = g_strdup( fma_formats[i].format );
+               str->label = g_strdup( gettext( fma_formats[i].label ));
+               str->description = g_strdup( gettext( fma_formats[i].description ));
+               if( fma_formats[i].image ){
+                       fname = g_strdup_printf( "%s/%s", PROVIDER_DATADIR, fma_formats[i].image );
                        str->pixbuf = gdk_pixbuf_new_from_file_at_size( fname, width, height, NULL );
                        g_free( fname );
 #if 0
@@ -134,12 +134,12 @@ nadp_formats_get_formats( const FMAIExporter* exporter )
 static void
 on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf )
 {
-       g_debug( "nadp_formats_on_pixbuf_finalized: exporter=%p, pixbuf=%p", ( void * ) exporter, ( void * ) 
pixbuf );
+       g_debug( "fma_formats_on_pixbuf_finalized: exporter=%p, pixbuf=%p", ( void * ) exporter, ( void * ) 
pixbuf );
 }
 #endif
 
 /**
- * nadp_formats_free_formats:
+ * fma_formats_free_formats:
  * @formats: a #GList to be freed.
  *
  * Returns: a #GList of the #FMAIExporterFormatv2 supported export formats.
@@ -149,7 +149,7 @@ on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf )
  * Since: 3.2
  */
 void
-nadp_formats_free_formats( GList *formats )
+fma_formats_free_formats( GList *formats )
 {
        GList *is;
        FMAIExporterFormatv2 *str;
@@ -74,20 +74,20 @@ static void on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf )
  * Returns: a #GList of the #FMAIExporterFormatv2 supported export formats.
  *
- * This list should be nadp_formats_free_formats() by the caller.
+ * This list should be fma_formats_free_formats() by the caller.
  *
  * Since: 3.2